aboutsummaryrefslogtreecommitdiffstats
path: root/libMpegTPDec/include/tpdec_lib.h
diff options
context:
space:
mode:
Diffstat (limited to 'libMpegTPDec/include/tpdec_lib.h')
-rw-r--r--libMpegTPDec/include/tpdec_lib.h17
1 files changed, 12 insertions, 5 deletions
diff --git a/libMpegTPDec/include/tpdec_lib.h b/libMpegTPDec/include/tpdec_lib.h
index fb4c41d..2ad397d 100644
--- a/libMpegTPDec/include/tpdec_lib.h
+++ b/libMpegTPDec/include/tpdec_lib.h
@@ -151,6 +151,7 @@ typedef enum {
#define PC_ASSOCDATA_MAX 8
#define PC_CCEL_MAX 16 /* CC elements */
#define PC_COMMENTLENGTH 256
+#define PC_NUM_HEIGHT_LAYER 3
/*!
@@ -239,14 +240,20 @@ int CProgramConfig_LookupElement(
);
/**
* \brief Get table of elements in canonical order.
* \param pPce A valid program config structure.
* \param table An array where the element IDs are stored.
* \return Total element count including all SCE, CPE and LFE.
*/
int CProgramConfig_GetElementTable( const CProgramConfig *pPce,
MP4_ELEMENT_ID table[],
- const INT elListSize );
+ const INT elListSize,
+ UCHAR *pChMapIdx );
/**
* \brief Initialize a given AudioSpecificConfig structure.
@@ -239,14 +240,20 @@ int CProgramConfig_LookupElement(
);
/**
- * \brief Get table of elements in canonical order.
- * \param pPce A valid program config structure.
- * \param table An array where the element IDs are stored.
- * \return Total element count including all SCE, CPE and LFE.
+ * \brief Get table of elements in canonical order from a
+ * give program config field.
+ * \param pPce A valid program config structure.
+ * \param table An array where the element IDs are stored.
+ * \param elListSize The length of the table array.
+ * \param pChMapIdx Pointer to a field receiving the corresponding
+ * implicit channel configuration index of the given
+ * PCE. If none can be found it receives the value 0.
+ * \return Total element count including all SCE, CPE and LFE.
*/
int CProgramConfig_GetElementTable( const CProgramConfig *pPce,